==> kubernetes-model-batch-5.9.0-sources.jar: io/fabric8/kubernetes/api/model/batch/v1/UncountedTerminatedPodsBuilder.java <==
package io.fabric8.kubernetes.api.model.batch.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class UncountedTerminatedPodsBuilder extends io.fabric8.kubernetes.api.model.batch.v1.UncountedTerminatedPodsFluentImpl<io.fabric8.kubernetes.api.model.batch.v1.UncountedTerminatedPodsBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.batch.v1.UncountedTerminatedPods,io.fabric8.kubernetes.api.model.batch.v1.UncountedTerminatedPodsBuilder>{
  public UncountedTerminatedPodsBuilder() {
    this(false);
  }
  public UncountedTerminatedPodsBuilder(java.lang.Boolean validationEnabled) {
    this(new UncountedTerminatedPods(), validationEnabled);
  }
  public UncountedTerminatedPodsBuilder(io.fabric8.kubernetes.api.model.batch.v1.UncountedTerminatedPodsFluent<?> fluent) {
    this(fluent, false);
  }
  public UncountedTerminatedPodsBuilder(io.fabric8.kubernetes.api.model.batch.v1.UncountedTerminatedPodsFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new UncountedTerminatedPods(), validationEnabled);
  }
  public UncountedTerminatedPodsBuilder(io.fabric8.kubernetes.api.model.batch.v1.UncountedTerminatedPodsFluent<?> fluent,io.fabric8.kubernetes.api.model.batch.v1.UncountedTerminatedPods instance) {
    this(fluent, instance, false);
  }
  public UncountedTerminatedPodsBuilder(io.fabric8.kubernetes.api.model.batch.v1.UncountedTerminatedPodsFluent<?> fluent,io.fabric8.kubernetes.api.model.batch.v1.UncountedTerminatedPods instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withFailed(instance.getFailed()); 
    fluent.withSucceeded(instance.getSucceeded()); 
    this.validationEnabled = validationEnabled; 
  }
  public UncountedTerminatedPodsBuilder(io.fabric8.kubernetes.api.model.batch.v1.UncountedTerminatedPods instance) {
    this(instance,false);
  }
  public UncountedTerminatedPodsBuilder(io.fabric8.kubernetes.api.model.batch.v1.UncountedTerminatedPods instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withFailed(instance.getFailed()); 
    this.withSucceeded(instance.getSucceeded()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.batch.v1.UncountedTerminatedPodsFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.batch.v1.UncountedTerminatedPods build() {
    UncountedTerminatedPods buildable = new UncountedTerminatedPods(fluent.getFailed(),fluent.getSucceeded());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    UncountedTerminatedPodsBuilder that = (UncountedTerminatedPodsBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-batch-5.10.2-sources.jar: io/fabric8/kubernetes/api/model/batch/v1/UncountedTerminatedPodsBuilder.java <==
package io.fabric8.kubernetes.api.model.batch.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class UncountedTerminatedPodsBuilder extends io.fabric8.kubernetes.api.model.batch.v1.UncountedTerminatedPodsFluentImpl<io.fabric8.kubernetes.api.model.batch.v1.UncountedTerminatedPodsBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.batch.v1.UncountedTerminatedPods,io.fabric8.kubernetes.api.model.batch.v1.UncountedTerminatedPodsBuilder>{
  public UncountedTerminatedPodsBuilder() {
    this(false);
  }
  public UncountedTerminatedPodsBuilder(java.lang.Boolean validationEnabled) {
    this(new UncountedTerminatedPods(), validationEnabled);
  }
  public UncountedTerminatedPodsBuilder(io.fabric8.kubernetes.api.model.batch.v1.UncountedTerminatedPodsFluent<?> fluent) {
    this(fluent, false);
  }
  public UncountedTerminatedPodsBuilder(io.fabric8.kubernetes.api.model.batch.v1.UncountedTerminatedPodsFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new UncountedTerminatedPods(), validationEnabled);
  }
  public UncountedTerminatedPodsBuilder(io.fabric8.kubernetes.api.model.batch.v1.UncountedTerminatedPodsFluent<?> fluent,io.fabric8.kubernetes.api.model.batch.v1.UncountedTerminatedPods instance) {
    this(fluent, instance, false);
  }
  public UncountedTerminatedPodsBuilder(io.fabric8.kubernetes.api.model.batch.v1.UncountedTerminatedPodsFluent<?> fluent,io.fabric8.kubernetes.api.model.batch.v1.UncountedTerminatedPods instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withFailed(instance.getFailed()); 
    fluent.withSucceeded(instance.getSucceeded()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public UncountedTerminatedPodsBuilder(io.fabric8.kubernetes.api.model.batch.v1.UncountedTerminatedPods instance) {
    this(instance,false);
  }
  public UncountedTerminatedPodsBuilder(io.fabric8.kubernetes.api.model.batch.v1.UncountedTerminatedPods instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withFailed(instance.getFailed()); 
    this.withSucceeded(instance.getSucceeded()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.batch.v1.UncountedTerminatedPodsFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.batch.v1.UncountedTerminatedPods build() {
    UncountedTerminatedPods buildable = new UncountedTerminatedPods(fluent.getFailed(),fluent.getSucceeded());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    UncountedTerminatedPodsBuilder that = (UncountedTerminatedPodsBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
